<?php
    function squirrelmail_plugin_init_get_uuencode() {
        global $squirrelmail_plugin_hooks;

        $squirrelmail_plugin_hooks["message_body"]["get_uuencode"] = "get_uuencode_message_body"; 
        $squirrelmail_plugin_hooks["read_body_bottom"]["get_uuencode"] = "get_uuencode_read_body_bottom";
    }
    function get_uuencode_message_body(&$data) {
        include_once(SM_PATH . 'plugins/get_uuencode/get_uuencode.php');
        get_uuencode_body($data);
    }
    function get_uuencode_read_body_bottom () {
        include_once(SM_PATH . 'plugins/get_uuencode/get_uuencode.php');
        get_uuencode_link();
    }
?>
